

def recurring_fibonacci_number(number:int)-> None | int:
    if number < 0:
        return None
    elif number <=1:
        return number
    else:
        return recurring_fibonacci_number(number-1) + recurring_fibonacci_number(number-2)



from unittest import main, TestCase
from unittest.mock import patch
from fib_py_example.fib_calcs.fib_numbers import calculate_numbers

class Test(TestCase):

    @patch("fib_py.fib_calcs.fib_numbers.recurring_fibonacci_number")
    def test_calculate_numbers(self, mock_fib_calc):
        expected_outcome = [mock_fib_calc.return_value, mock_fib_calc.return_value]
        self.assertEqual(expected_outcome, calculate_numbers(numbers=[3, 4]))
        self.assertEqual(2, len(mock_fib_calc.call_args_list))

        self.assertEqual({"number": 3}, mock_fib_calc.call_args_list[0][1])
        self.assertEqual({"number": 4}, mock_fib_calc.call_args_list[1][1])
    
    def test_function(self):
        self.assertEqual([2,3,5], calculate_numbers(numbers=[3,4,5]))

if __name__ == "__main__":
    main()


import argparse
from fib_py_example.fib_calcs.fib_number import recurring_fibonacci_number

def fib_numb()->None:
    parser = argparse.ArgumentParser(
        description="Calculate Fibonacci numbers"
    )
    parser.add_argument('--number', action='store', type=int, required=True, help="Fibonacci number to be calculated")
    args = parser.parse_args()

    print(f"Your Fibonacci number is : {recurring_fibonacci_number(number=args.number)}")


from setuptools import find_packages, setup
with open("README.md", 'r') as f:
    long_description = f.read()


setup(
    name="fib_py_example",
    version="0.1.1",
    author="David zhang",
    author_email="spartazhangzhang@gmail.com",
    description="Calculates a Fibonacci number",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/spartazhangzhang/python-fib",

    install_requires=[],
    packages=find_packages(exclude=("tests",)),
    classifiers=[
        "Development Status :: 4 - Beta",

        "Programming Language :: Python :: 3",

        "Operating System :: OS Independent",

    ],
    python_requires='>=3.10',
    tests_require=['pytest'],
    entry_points={
    'console_scripts': [
        'fib-number = fib_py_example.cmd.fib_numb:fib_numb',
    ],

},
)